@@ -15,12 +15,13 @@ import requests
 
 from instagrapi import config
 from instagrapi.exceptions import (
+    ClientThrottledError,
     PleaseWaitFewMinutes,
     PrivateError,
     ReloginAttemptExceeded,
     TwoFactorRequired,
 )
-from instagrapi.utils import dumps, generate_jazoest, gen_token
+from instagrapi.utils import dumps, gen_token, generate_jazoest
 from instagrapi.zones import CET
 
 
@@ -242,7 +243,7 @@ class PostLoginFlowMixin:
 class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
     username = None
     password = None
-    authorization = ''  # Bearer IGT:2:<base64:authorization_data>
+    authorization = ""  # Bearer IGT:2:<base64:authorization_data>
     authorization_data = {}  # decoded authorization header
     last_login = None
     relogin_attempt = 0
@@ -252,10 +253,10 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
     device_id = ""
     phone_id = ""
     uuid = ""
+    mid = ""
     country = "US"
     locale = "en_US"
-    timezone_offset = "10800"
-    mid = ''
+    timezone_offset: int = -14400  # New York, GMT-4 in seconds
 
     def __init__(self):
         self.user_agent = None
@@ -353,7 +354,8 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
             return True  # already login
         try:
             self.pre_login_flow()
-        except PleaseWaitFewMinutes:
+        except (PleaseWaitFewMinutes, ClientThrottledError):
+            self.logger.warning('Ignore 429: Continue login')
             # The instagram application ignores this error
             # and continues to log in (repeat this behavior)
             pass
