@@ -216,6 +216,16 @@ class Story(BaseModel):
     stickers: List[StorySticker]
 
 
+class DirectMedia(BaseModel):
+    id: str
+    media_type: int
+    thumbnail_url: Optional[HttpUrl]
+    user: Optional[UserShort]
+    like_count: int
+    caption_text: str
+    video_url: Optional[HttpUrl]
+
+
 class DirectMessage(BaseModel):
     id: int  # e.g. 28597946203914980615241927545176064
     user_id: Optional[int]
@@ -225,6 +235,7 @@ class DirectMessage(BaseModel):
     is_shh_mode: Optional[bool]
     reactions: Optional[dict]
     text: Optional[str]
+    media: Optional[DirectMedia]
     media_share: Optional[Media]
     reel_share: Optional[dict]
     story_share: Optional[dict]
